import { OnInit } from '@angular/core';
import { TableColumnContainer } from '../../abstract/table-column-container';
import { TableColumnDirective } from './table-column.directive';
/**
 * Directive used to simplify the creation of table headers; it provides
 * utilities to transform the following:
 * ```html
 * <lf-table-header>
 *   <lf-table-column id="name">
 *     <lf-table-column id="first"></lf-table-column>
 *     <lf-table-column id="last"></lf-table-column>
 *   </lf-table-column>
 *   <lf-table-column id="age"></lf-table-column>
 * </lf-table-header>
 * ```
 * Into a header similar to:
 * ```
 * |     Name     |     |
 * |--------------| Age |
 * | First | Last |     |
 * ```
 * The directive provides a method to help the underlying table set column sizes
 * (using `<colgroup>`) when necessary, in which case the underlying `<table>`
 * element should have the CSS property `table-layout` set to `fixed` (forcing
 * table columns to not vary depending on cell content).
 */
export declare class TableHeaderDirective extends TableColumnContainer implements OnInit {
    /**
     * Default min width (in `px`) of columns.
     */
    defaultColumnsMinWidth: number;
    /**
     * Total number of rows of the header (should map to the number of `<tr>` of
     * the actual header).
     * @returns Number of rows of the header.
     */
    readonly numberOfRows: number;
    /**
     * Number of (leaf) columns of the header (number of columns actually
     * representing table cells/that don't have sub-columns).
     * @returns Number of leaf columns of the header.
     */
    readonly numberOfColumns: number;
    /**
     * List of rows of the header, where each row contains a list of its columns.
     * This should directly map each row to a `<tr>` of the header, and each
     * column to a `<th>`. For the example depicted in the class definition
     * comment, this method would return: `[[Name, Age], [First, Last]]`.
     * @returns List of rows, where each row is a list of columns.
     */
    readonly rows: TableColumnDirective[][];
    /**
     * Minimum width (in pixels) that should be set on the table that contains
     * this header. If the table does not have a min width, then the columns will
     * collapse indefinitly, we thus set a minimum width that amounts to the sum
     * of the minimum width of all columns.
     * @returns Minimum width (in pixels) that should be set on the table.
     */
    readonly tableMinWidth: number;
    /**
     * Maximum width (in pixels) that should be set on the table that contains
     * this header. Tables where all the columns have a fixed width cannot ever
     * expand, for that we must set a max width on the table
     * @returns Maximum width (in pixels) that should be set on the table.
     */
    readonly tableMaxWidth: number;
    /**
     * Width for all table columns, as they should be set in CSS (strings ending
     * in `'px'` or `'%'` depending on whether the column is fixed). Each of these
     * widths should be put on a `<col>` element inside a `<colgroup>` before the
     * definition of the `<thead>` that contains this table header.
     * @returns List of widths of each leaf column.
     */
    readonly columnWidths: string[];
    /**
     * Method that returns the list of leaf columns: columns whose label directly
     * represents a table cell/columns that contain no sub-columns. For the
     * example depicted in the class definition comment, this method would return:
     * `[First, Last, Age]`.
     * @param columnContainer For internal use only (to recurse over columns).
     * @returns List of columns that are leaves.
     */
    private _leafColumns;
    /**
     * Method that returns the list of columns of a given row (`<tr>`) of the
     * table header. For the example depicted in the class definition comment,
     * for row `0` this method would return `[Name, Age]`; for row `1` it would
     * return `[First, Last]`.
     * @param index Index of row from which to fetch columns.
     * @param columnContainer For internal use only (to recurse over columns).
     * @returns List of columns of row with index `index`.
     */
    private _columnsOfRow;
    /**
     * Minimum width of a column (or a default minimum width when none has been
     * created).
     * @param column Column whose minimum width we are interested in.
     * @returns Minimum width of the column.
     */
    private _columnMinWidth;
}
